@@ -9,9 +9,9 @@
 
 #include <memory>
 
+#include <QFuture>
 #include <QObject>
 #include <QString>
-#include <QFuture>
 
 #include "SkanpageUtils.h"
 
@@ -22,9 +22,8 @@ class DocumentPrinter : public QObject
     Q_OBJECT
 
 public:
-
     explicit DocumentPrinter(QObject *parent = nullptr);
-    ~DocumentPrinter();
+    ~DocumentPrinter() override;
 
     void printDocument(const SkanpageUtils::DocumentPages &document);
 
